@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2010 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2011 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,36 +18,24 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-
-/*
-** Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
-**
-** This file is part of the example classes of the Qt Toolkit.
-**
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.
+/* some code by
+Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
 */
 
 /*
 code from qPEditor:
-
 *   Copyright (C) 2007 by Michael Protasov
-*   mik-protasov@anyqsoft.com
-
-*/
+*   mik-protasov@anyqsoft.com */
 
 /*
-Diego Iastrubni <elcuco@kde.org> //some GPL'ed code from new-editor-diego-3, found on qtcentre forum
+Diego Iastrubni <elcuco@kde.org> //some GPL'ed code from new-editor-diego-3,
+found on qtcentre forum
 */
 
 /*
 code from qwriter:
-
- *   Copyright (C) 2009 by Gancov Kostya                                   *
- *   kossne@mail.ru                                                        *
-
+*   Copyright (C) 2009 by Gancov Kostya                                   *
+*   kossne@mail.ru                                                        *
 */
 
 
@@ -82,8 +70,7 @@ void CDocument::update_status()
 
   x = cursorOffset - off + 1;
 
-  holder->l_status_bar->setText (
-                                 QString ("%1:%2 %3").arg (
+  holder->l_status_bar->setText (QString ("%1:%2 %3").arg (
                                  QString::number (y)).arg (
                                  QString::number (x)).arg (charset));
 }
@@ -91,7 +78,7 @@ void CDocument::update_status()
 
 void CDocument::update_title (bool fullname)
 {
-  QMainWindow *w = qobject_cast<QMainWindow *>(holder->parent_wnd);
+  QMainWindow *w = qobject_cast <QMainWindow *> (holder->parent_wnd);
 
   if (fullname)
      w->setWindowTitle (file_name);
@@ -170,8 +157,8 @@ bool CDocument::save_with_name (const QString &fileName, const QString &codec)
   if (! tio->save (fileName))
      {
       holder->log->log (tr ("cannot save %1 because of: %2")
-                           .arg (fileName)
-                           .arg (tio->error_string));
+                        .arg (fileName)
+                        .arg (tio->error_string));
       return false;
      }
 
@@ -198,7 +185,7 @@ CDocument::CDocument (QObject *parent): QObject (parent)
   fnameswoexts.insert ("configure", "sh");
   fnameswoexts.insert ("install-sh", "sh");
   
-  markup_mode = "HML";
+  markup_mode = "HTML";
   file_name = fname;
   cursor_xy_visible = true;
   charset = "UTF-8";
@@ -210,6 +197,10 @@ CDocument::CDocument (QObject *parent): QObject (parent)
 
   def_eol = "\r\n";
 
+#elif defined(Q_OS_OS2)
+
+  def_eol = "\r\n";
+
 #else
 
   def_eol = "\n";
@@ -233,7 +224,7 @@ CDocument::~CDocument()
                                 .arg (file_name),
                                 QMessageBox::Ok | QMessageBox::Default,
                                 QMessageBox::Cancel | QMessageBox::Escape) == QMessageBox::Ok)
-          save_with_name (file_name, charset);
+         save_with_name (file_name, charset);
      }
 
   if (file_name != holder->fname_crapbook)
@@ -246,7 +237,6 @@ CDocument::~CDocument()
   if (file_name.startsWith (holder->todo.dir_days))
       holder->todo.load_dayfile();
 
-
   int i = holder->tab_widget->indexOf (tab_page);
   if (i != -1)
      holder->tab_widget->removeTab (i);
@@ -331,7 +321,10 @@ CDocument* document_holder::open_file (const QString &fileName, const QString &c
      {
       CDocument *td = get_current();
       if (td)
-         td->insert_image (fileName);  
+         {
+          td->insert_image (fileName);
+          td->textEdit->setFocus (Qt::OtherFocusReason);
+         }
       return td;
      }   
    
@@ -435,7 +428,8 @@ QString CDocument::get_filename_at_cursor()
 }
 
 
-CSyntaxHighlighter::CSyntaxHighlighter (QTextDocument *parent, CDocument *doc): QSyntaxHighlighter (parent)
+CSyntaxHighlighter::CSyntaxHighlighter (QTextDocument *parent, CDocument *doc):
+                                        QSyntaxHighlighter (parent)
 {
   document = doc;
   casecare = true;
@@ -585,9 +579,9 @@ void document_holder::update_recent_menu()
 
 void document_holder::open_recent()
 {
-  QAction *Act = qobject_cast<QAction *>(sender());
+  QAction *act = qobject_cast<QAction *>(sender());
 
-  int i = recent_files.indexOf (Act->text ());
+  int i = recent_files.indexOf (act->text ());
   if (i == -1)
      return;
 
@@ -719,6 +713,7 @@ void CTEAEdit::paintEvent (QPaintEvent *event)
   if (draw_margin)
      {
       QPainter painter (viewport());
+
       QPen pen = painter.pen();
       pen.setColor (margin_color);
       painter.setPen (pen);
@@ -743,8 +738,9 @@ void CTEAEdit::paintEvent (QPaintEvent *event)
 
 void CTEAEdit::setup_brace_width()
 {
-  QFontMetrics *fm = new QFontMetrics (currentCharFormat().font());
-  brace_width = fm->width ("9");
+ // QFontMetrics *fm = new QFontMetrics (currentCharFormat().font());
+  QFontMetrics *fm = new QFontMetrics (font());
+  brace_width = fm->averageCharWidth(); //fm->width ("9");
 }
 
 
@@ -786,7 +782,10 @@ void CTEAEdit::dropEvent (QDropEvent *event)
              doc->holder->open_file (fName, "UTF-8");
          }
 
-  event->acceptProposedAction();
+//  event->acceptProposedAction();
+//  event->accept();
+
+  QPlainTextEdit::dropEvent(event);
 }
 
     
@@ -882,7 +881,7 @@ void CSyntaxHighlighter::highlightBlock (const QString &text)
          int commentLength;
          if (endIndex == -1)
             {
-             setCurrentBlockState(1);
+             setCurrentBlockState (1);
              commentLength = text.length() - startIndex;
             }
          else
@@ -959,7 +958,7 @@ void CSyntaxHighlighter::load_from_xml (const QString &fname)
                 }
 
 
-             if (e.attribute("type") == "keywords")
+             if (e.attribute ("type") == "keywords")
                 {
                  //qDebug () << e.attribute ("name");
                  QString color = hash_get_val (document->holder->palette, e.attribute ("color"), "darkBlue");
@@ -978,8 +977,7 @@ void CSyntaxHighlighter::load_from_xml (const QString &fname)
                          }
                      }   
                  }
-
-
+             else
              if (e.attribute("type") == "item")
                 {
                  QString color = hash_get_val (document->holder->palette, e.attribute("color"), "darkBlue");
@@ -990,8 +988,7 @@ void CSyntaxHighlighter::load_from_xml (const QString &fname)
                  rule.format = fmt;
                  highlightingRules.append(rule);
                 }
-
-
+             else
              if (e.attribute("type") == "mcomment-start")
                 {
                  QString color = hash_get_val (document->holder->palette, e.attribute("color"), "gray");
@@ -1000,33 +997,30 @@ void CSyntaxHighlighter::load_from_xml (const QString &fname)
                  multiLineCommentFormat = fmt;
                  commentStartExpression = QRegExp (e.text().trimmed());
                 }
-
+             else
              if (e.attribute("type") == "mcomment-end")
                 commentEndExpression = QRegExp (e.text().trimmed());
-                
-                
+             else
              if (e.attribute("type") == "comment")
                 {
                  if (e.attribute ("name") == "cm_mult")
                     cm_mult = e.text().trimmed();
-
+                 else
                  if (e.attribute ("name") == "cm_single")
                     cm_single = e.text().trimmed();
                 }
-   
-                
             }
 
          n = n.nextSibling();
         }
 }
 
-
+/*
 CTEAEdit::~CTEAEdit()
 {
   qDebug() << "~CTEAEdit";
 }
-
+*/
 
 void document_holder::save_to_session (const QString &fileName)
 {
@@ -1051,7 +1045,7 @@ void document_holder::load_from_session (const QString &fileName)
   if (! file_exists (fileName))
      return;
 
-  QStringList l = qstring_load (fileName).split("\n");
+  QStringList l = qstring_load (fileName).split ("\n");
   int c = l.size();
   if (c < 0)
      return;
@@ -1143,8 +1137,8 @@ void CTEAEdit::indent()
       else
           textCursor().insertText ("\t");
        
-       return;
-      }
+      return;
+     }
 
   QStringList l = textCursor().selectedText().split (QChar::ParagraphSeparator);
        
@@ -1159,7 +1153,7 @@ void CTEAEdit::indent()
          if (spaces_instead_of_tabs)
             i.setValue (s.prepend (fl));
          else
-              i.setValue (s.prepend ("\t"));
+             i.setValue (s.prepend ("\t"));
          }       
        
   textCursor().insertText (l.join ("\n"));
@@ -1192,13 +1186,11 @@ void CTEAEdit::un_indent()
          QString t = i.next();
          
          if (! t.isEmpty() && (t.size() > 1)) 
-            {
              if (t[0] == '\t' || t[0].isSpace())
                 {
                  t = t.mid (1);
                  i.setValue (t);
                 }              
-            }
          }       
    
   textCursor().insertText (l.join ("\n"));
@@ -1214,13 +1206,13 @@ void CTEAEdit::un_indent()
 void CTEAEdit::keyPressEvent (QKeyEvent *event)
 {
    if (auto_indent)
-   if (event->key() == Qt::Key_Return)
-      {
-       calc_auto_indent();
-       QPlainTextEdit::keyPressEvent (event);
-       textCursor().insertText (indent_val);
-       return;
-      }
+      if (event->key() == Qt::Key_Return)
+         {
+          calc_auto_indent();
+          QPlainTextEdit::keyPressEvent (event);
+          textCursor().insertText (indent_val);
+          return;
+         }
    
    if (event->key() == Qt::Key_Tab)
       {
@@ -1254,7 +1246,7 @@ int CTEAEdit::lineNumberAreaWidth()
          ++digits;
         }
 
-  int space = 18 + brace_width * digits;
+  int space = (brace_width * 2) + (brace_width * digits);
 
   return space;
 }
@@ -1316,7 +1308,7 @@ void CTEAEdit::lineNumberAreaPaintEvent (QPaintEvent *event)
 }
 
 
-void CTEAEdit::resizeEvent(QResizeEvent *e)
+void CTEAEdit::resizeEvent (QResizeEvent *e)
 {
   QPlainTextEdit::resizeEvent (e);
   QRect cr = contentsRect();
@@ -1431,7 +1423,7 @@ void CTEAEdit::braceHighlight()
             if (cursor2.isNull()) 
                {
                 selection.cursor = cursor;
-                extraSelections.append(selection);
+                extraSelections.append (selection);
                 selection.cursor = cursor1;
                 extraSelections.append (selection);
                 setExtraSelections (extraSelections);
