@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2010 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2011 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -94,7 +94,7 @@ public:
 
 
   CTEAEdit (QWidget *parent = 0);
-  ~CTEAEdit();
+  //~CTEAEdit();
 
   void setCurrentLineColor (const QColor &newColor);
   void set_brackets_color (const QColor &newColor);
@@ -159,7 +159,7 @@ public:
     
   CSyntaxHighlighter (QTextDocument *parent = 0, CDocument *doc = 0);
 
-  QVector<HighlightingRule> highlightingRules;
+  QVector <HighlightingRule> highlightingRules;
 
   QTextCharFormat singleLineCommentFormat;
   QTextCharFormat multiLineCommentFormat;
@@ -243,7 +243,6 @@ public:
 
   QLabel *l_status_bar;
   QString dir_config;
-  //QString dir_days;
 
   QString fname_crapbook;
 
