@@ -1,5 +1,5 @@
  /**************************************************************************
- *   Copyright (C) 2007-2010 by Peter Semiletov                            *
+ *   Copyright (C) 2007-2011 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,7 +34,8 @@ void CFMan::dir_up()
   nav (dir.path());
 
   QModelIndex index = index_from_name (oldcurdir);
-  tree_view->selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select | QItemSelectionModel::Rows);
+  tree_view->selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select |
+                                                       QItemSelectionModel::Rows);
   tree_view->scrollTo (index);
 }
 
@@ -49,10 +50,15 @@ void CFMan::nav (const QString &path)
 
   model->removeRows (0, model->rowCount());
   QFileInfoList lst = dir.entryInfoList (QDir::Dirs | QDir::Hidden | QDir::NoDotAndDotDot |
-                                         QDir::Files | QDir::Drives,
-                                         QDir::Name | QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware);
+                                         QDir::Files | QDir::Drives, QDir::Name |
+                                         QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware);
 
-#ifndef Q_WS_WIN
+#if defined (Q_WS_WIN)
+
+  if (path != "/")
+     append_dot_entry ("..");
+
+#elif defined (Q_OS_OS2)
 
   if (path != "/")
      append_dot_entry ("..");
@@ -85,14 +91,13 @@ const QModelIndex CFMan::index_from_name (const QString &name)
 
 void CFMan::tv_activated (const QModelIndex &index)
 {
-  QString oldcurdir = dir.dirName();
   QString item_string = index.data().toString();
   
   QString dpath = dir.path();
   
   if (dpath.size() > 1)
-  if (dpath.endsWith("/") || dpath.endsWith("\\"))
-   	  dpath.truncate(dpath.size() - 1); 
+     if (dpath.endsWith("/") || dpath.endsWith("\\"))
+      	  dpath.truncate(dpath.size() - 1);
     
   QString full_path;
   
@@ -111,7 +116,8 @@ void CFMan::tv_activated (const QModelIndex &index)
      {
       nav (full_path);
       QModelIndex index = model->index (0, 0);
-      tree_view->selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select | QItemSelectionModel::Rows);
+      tree_view->selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select |
+                                                           QItemSelectionModel::Rows);
 
       return;
      }
@@ -139,7 +145,7 @@ void CFMan::add_entry (const QFileInfo &fi)
   item->setFlags (Qt::ItemIsSelectable | Qt::ItemIsEnabled);
   items.append (item);
 
-  item = new QStandardItem (fi.lastModified().toString("yyyy-MM-dd"));
+  item = new QStandardItem (fi.lastModified().toString ("yyyy-MM-dd"));
   item->setFlags (Qt::ItemIsSelectable | Qt::ItemIsEnabled);
   items.append (item);
 
@@ -199,7 +205,18 @@ CFMan::CFMan (QObject *parent): QObject (parent)
 
 void CFMan::cb_fman_currentChanged (const QModelIndex &current, const QModelIndex &previous )
 {
-  QString item_string = current.data().toString();
+  int row = current.row();
+  if (row < 0)
+     {
+      emit current_file_changed ("", "");
+      return;
+     }
+
+  QModelIndex i = tree_view->model()->index (row, 0);
+
+  //QString item_string = current.data().toString();
+  QString item_string = i.data().toString();
+
   QString full_path = dir.path() + "/" + item_string;
 
   if (! is_dir (full_path))
@@ -260,7 +277,6 @@ void CFMan::refresh()
 
   nav (dir.path());
 
-  qDebug() << current;
   QModelIndex index = index_from_name (current);
   tree_view->selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select | QItemSelectionModel::Rows);
   tree_view->scrollTo (index);
