@@ -28,7 +28,8 @@ void CImgViewer::set_image_mini (const QString &fname)
   else 
       {
        QPixmap pm (fname);
-       if ((pm.width() > (window_mini.width() - 10)) || (pm.height() > (window_mini.height() - 10)))
+       if ((pm.width() > (window_mini.width() - 10)) ||
+           (pm.height() > (window_mini.height() - 10)))
           img_mini->setPixmap (pm.scaled (190, 190, Qt::KeepAspectRatio));
        else
            img_mini->setPixmap (pm);
@@ -41,17 +42,17 @@ void CImgViewer::set_image_full (const QString &fname)
   window_full.show_image (fname);
 }
 
-
+/*
 void CImgViewer::set_image_full_clipboard()
 {
   window_full.show_image_from_clipboard();
 }
-
-
+*/
 
 QString CImgViewer::get_the_thumb_name (const QString &img_fname)
 {
  
+//FIXME: add OS2 tweak!
 #ifndef Q_WS_WIN  
  
   QCryptographicHash h (QCryptographicHash::Md5); 
@@ -88,7 +89,6 @@ CViewerWindow::CViewerWindow (QWidget *parent): QWidget (parent)
   angle = 0.0;
   scale = 100;
   
-  //rubber_band = new  QRubberBand (QRubberBand::Rectangle, this);
   img_full = new QLabel (tr ("preview"));
   img_full->setAlignment (Qt::AlignCenter);
   QVBoxLayout *lt = new QVBoxLayout;
@@ -156,11 +156,6 @@ void CViewerWindow::show_again()
   QImage pm (file_name);
   if (scale != 100)
      pm = pm.scaledToWidth (get_value (pm.width(), scale));
-
-  //int rb_w = get_value (rubber_band->width(), scale);
-  //int rb_h = get_value (rubber_band->height(), scale);
-    
-  //rubber_band->resize (rb_w, rb_h);
                            
   QTransform transform;
   transform.rotate (angle);
@@ -263,7 +258,7 @@ void CViewerWindow::keyPressEvent (QKeyEvent *event)
   QWidget::keyPressEvent (event);
 }
 
-
+/*
 void CViewerWindow::show_image_from_clipboard()
 {
   
@@ -286,27 +281,4 @@ void CViewerWindow::show_image_from_clipboard()
   s_wnd_title.append (QString (" - %1x%2").arg (pm.width()).arg(pm.height()));
   setWindowTitle (s_wnd_title);
 }
-
-/*
-
-void CViewerWindow::mousePressEvent(QMouseEvent *event)
- {
-  orgn = event->pos();
-     //if (!rubberBand)
-       //  rubberBand = new QRubberBand(QRubberBand::Rectangle, this);
-     rubber_band->setGeometry(QRect(orgn, QSize()));
-     rubber_band->show();
- }
-
-void CViewerWindow::mouseMoveEvent(QMouseEvent *event)
- {
-     rubber_band->setGeometry(QRect(orgn, event->pos()).normalized());
- }
-
- void CViewerWindow::mouseReleaseEvent(QMouseEvent *event)
- {
-     //rubber_band->hide();
-     // determine selection, for example using QRect::intersects()
-     // and QRect::contains().
- }
 */
