@@ -23,7 +23,7 @@ public:
    
    CViewerWindow (QWidget *parent = 0);
    void show_image (const QString &fname);
-   void show_image_from_clipboard();
+//   void show_image_from_clipboard();
 
    void show_again();
    
@@ -50,7 +50,7 @@ public:
   CImgViewer (QObject *parent = 0);
   void set_image_mini (const QString &fname);
   void set_image_full (const QString &fname);
-  void set_image_full_clipboard();
+  //void set_image_full_clipboard();
 
   QString get_the_thumb_name (const QString &img_fname);
 };
