@@ -219,6 +219,7 @@ public:
   QLabel *l_status;
   QProgressBar *pb_status;
   QLineEdit *ed_spellcheck_path;
+  QLineEdit *ed_aspellcheck_path;
 
   QCheckBox *cb_wordwrap;
   QCheckBox *cb_show_linenums;
@@ -395,6 +396,15 @@ main window callbacks
   void pb_choose_hunspell_path_clicked();
 #endif
 
+
+#ifdef ASPELL_ENABLE
+
+#if defined(Q_WS_WIN) || defined (_OS_OS2)
+   void pb_choose_aspell_path_clicked();
+#endif
+
+#endif
+
 #endif
 
   void search_in_files_results_dclicked (QListWidgetItem *item);
@@ -539,18 +549,16 @@ prefs window callbacks
 
   void guess_enc();
 
-#ifndef Q_OS_OS2
-  
+/*  
   void fn_show_image_from_clipboard();
   void fn_capture_screen();
   void capt_active_wnd_image();
   void capt_desktop_image();
   void image_save_from_clipboard();
 
-#endif
 
   void screenshot_delay_changed (int i);
-
+*/
 
   void cal_add_days();
   void cal_add_months();
