@@ -32,9 +32,10 @@
 
 #ifdef ASPELL_ENABLE
 
-CSpellchecker::CSpellchecker (const QString &lang, const QString &path, const QString &user_path): ASpellchecker (lang, path, user_path)
+CSpellchecker::CSpellchecker (const QString &lang, const QString &path,
+                              const QString &user_path):
+                              ASpellchecker (lang, path, user_path)
 {
- 
   ret = NULL;
   speller = NULL;
   
@@ -45,6 +46,20 @@ CSpellchecker::CSpellchecker (const QString &lang, const QString &path, const QS
   aspell_config_replace (spell_config, "lang", lang.toUtf8().data());
   aspell_config_replace (spell_config, "encoding", "UTF-8");
 
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+
+  QString data_path = path + "/data";
+  QString dict_path = path + "/dict";
+
+  //aspell_config_replace (spell_config, "data-dir", "C:/Program Files/Aspell/data");
+  //aspell_config_replace (spell_config, "dict-dir", "C:/Program Files/Aspell/dict");
+
+  aspell_config_replace (spell_config, "data-dir", data_path.toAscii().data());
+  aspell_config_replace (spell_config, "dict-dir", dict_path.toAscii().data());
+
+#endif
+
+  
   ret = new_aspell_speller (spell_config);
   if (! ret)
      return;
@@ -130,8 +145,11 @@ QStringList CSpellchecker::get_speller_modules_list()
   dels = aspell_dict_info_list_elements (dlist);
 
   while ((entry = aspell_dict_info_enumeration_next (dels)) != 0)
-        if (entry)
+        {
+		 if (entry)
            l.prepend (entry->name);
+           qDebug()	<< entry->name;	   
+		 }  
 
   delete_aspell_dict_info_enumeration (dels);
 
