@@ -38,7 +38,9 @@ class ASpellchecker//: public QObject
 
 public:
 
-  ASpellchecker (const QString &lang, const QString &path = "", const QString &user_path = "") {};
+  ASpellchecker (const QString &lang,
+                 const QString &path = "",
+                 const QString &user_path = "") {};
 
   virtual ~ASpellchecker() {};
 
