@@ -322,8 +322,9 @@ bool CTioRTF::load (const QString &fname)
   else
       {
        ansicgp.prepend ("CP");
+       
        QTextCodec *codec = QTextCodec::codecForName (ansicgp.toUtf8().data());
-       //qDebug() << "not unicode!";
+       qDebug() << "not unicode!";
 
        while (i < l)
        if ((ba.at(i) == '\\') && (ba.at(i + 1) == '\''))
