@@ -79,10 +79,6 @@ Do you want to save your changes?</source>
         <source>preview</source>
         <translation>Vorschau</translation>
     </message>
-    <message>
-        <source>Clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -116,10 +112,6 @@ Do you want to save your changes?</source>
         <source>&lt;b&gt;TEA %1 @ http://tea-editor.sourceforge.net&lt;/b&gt;&lt;br&gt;by Peter Semiletov (peter.semiletov@gmail.com)&lt;br&gt;read the Manual under the &lt;i&gt;learn&lt;/i&gt; tab!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>All (*);;Text files (*.txt);;Markup files (*.xml *.html *.htm *.);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Charset</source>
         <translation>Zeichensatz</translation>
@@ -1300,18 +1292,6 @@ opera=opera %s</source>
         <source>Comment selection</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Capture active window</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Capture desktop</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show image from clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Calendar</source>
         <translation type="unfinished"></translation>
@@ -1356,18 +1336,6 @@ opera=opera %s</source>
         <source>Miscellaneous</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Screen capture delay, seconds</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Screenshot was copied to clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Screenshot was saved to %1</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>todo</source>
         <translation type="unfinished"></translation>
@@ -1376,10 +1344,6 @@ opera=opera %s</source>
         <source>Enter your daily notes here.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Save image from clipboard to file</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Enter your daily notes here.
 To use time-based reminders, specify the time signature in 24-hour format [hh:mm], i.e.:
@@ -1387,5 +1351,13 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
 [20:10]go to theatre</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>All (*);;Text files (*.txt);;Markup files (*.xml *.html *.htm *.);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++ *.cxx)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aspell directory</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
