@@ -265,7 +265,7 @@ QString toggle_fname_header_source (const QString &fileName)
       if (file_exists (f.absolutePath() + "/" + f.baseName () + ".hpp"))
         return f.absolutePath() + "/" + f.baseName () + ".hpp";
      }
-
+  else
   if (ext == "h" || ext == "h++" || ext == "hxx" || ext == "hh" || ext == "hpp")
      {
       if (file_exists (f.absolutePath() + "/" + f.baseName () + ".c"))
@@ -375,7 +375,7 @@ QByteArray file_load (const QString &fileName)
   QByteArray b;
 
   if (! file.open (QFile::ReadOnly))
-       return b;
+      return b;
 
   b = file.readAll();
   return b;
@@ -400,7 +400,8 @@ void create_menu_from_dir (QObject *handler,
   menu->setTearOffEnabled (true); 
   QDir d (dir);
   QFileInfoList lst_fi = d.entryInfoList (QDir::NoDotAndDotDot | QDir::AllEntries,
-                                          QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware | QDir::Name);
+                                          QDir::DirsFirst | QDir::IgnoreCase |
+                                          QDir::LocaleAware | QDir::Name);
 
   foreach (QFileInfo fi, lst_fi)
          {
@@ -421,10 +422,10 @@ void create_menu_from_dir (QObject *handler,
 }
 
 
-QPixmap pixmap_scale_by (const QPixmap &source,
-                         bool by_side,
-                         int value,
-                         Qt::TransformationMode mode)
+QImage image_scale_by (const QImage &source,
+                       bool by_side,
+                       int value,
+                       Qt::TransformationMode mode)
 {
   bool horisontal = (source.width() > source.height());
 
@@ -442,13 +443,10 @@ QPixmap pixmap_scale_by (const QPixmap &source,
         height = get_value (source.height(), value);
        }
 
-  QPixmap dest;
   if (horisontal)
-     dest = source.scaledToWidth (width, mode);
+     return source.scaledToWidth (width, mode);
   else
-      dest = source.scaledToHeight (height, mode);
-
-  return dest;
+      return source.scaledToHeight (height, mode);
 }
 
 
@@ -527,20 +525,20 @@ bool CWavReader::get_info (const QString fname)
         {
          ds.readRawData ((char *)&hdr, sizeof (hdr));
          
-         if (str_check (hdr.chunk_id, "RIFF", 4))
+         if (str_check (hdr.chunk_id, (char*)"RIFF", 4))
             {
              char riff_type[4];
              ds.readRawData ((char *)&riff_type, sizeof (riff_type));
            } 
          else
-         if (str_check (hdr.chunk_id, "fmt ", 4))
+         if (str_check (hdr.chunk_id, (char*)"fmt ", 4))
             {
              ds.readRawData ((char *)&wav_chunk_fmt, sizeof (wav_chunk_fmt));
              if (wav_chunk_fmt.bits_per_sample != 16)
                 return false; 
             } 
          else
-         if (str_check (hdr.chunk_id, "data", 4))
+         if (str_check (hdr.chunk_id, (char*)"data", 4))
             {
              int nsamples = hdr.chunk_size / (wav_chunk_fmt.bits_per_sample / 8);
              
@@ -605,7 +603,7 @@ unsigned int bin_to_decimal (const QString &s)
   unsigned int c = 1;
   unsigned int result = 0;
   QString sn = string_reverse (s);
-  qDebug() << sn;
+
   table[0] = 1;
   
   for (int i = 1; i < 32; i++)
@@ -661,7 +659,8 @@ void CFilesList::iterate (QFileInfo &fi)
   if (fi.isDir())
      {
       QDir d (fi.absoluteFilePath());
-      QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files | QDir::Readable | QDir::NoDotAndDotDot);
+      QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files |
+                                          QDir::Readable | QDir::NoDotAndDotDot);
       for (int i = 0; i < lfi.count(); i++)
            iterate (lfi[i]);
      }
@@ -675,7 +674,8 @@ void CFilesList::get (const QString &path)
 {
   list.clear();
   QDir d (path);
-  QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files | QDir::Readable | QDir::NoDotAndDotDot);
+  QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files |
+                                      QDir::Readable | QDir::NoDotAndDotDot);
   for (int i = 0; i < lfi.count(); i++)
       iterate (lfi[i]);
 }
