@@ -112,10 +112,11 @@ void create_menu_from_dir (QObject *handler,
                            const QString &dir,
                            const char *method
                            );
-QPixmap pixmap_scale_by (const QPixmap &source,
-                         bool by_side,
-                         int value,
-                         Qt::TransformationMode mode);
+
+QImage image_scale_by (const QImage &source,
+                       bool by_side,
+                       int value,
+                       Qt::TransformationMode mode);
 
 QString change_file_ext (const QString &s, const QString &ext);
 QStringList bytearray_to_stringlist (QList <QByteArray> a);
@@ -128,7 +129,8 @@ QString get_insert_image (const QString &file_name, const QString &full_path, co
 
 inline int get_value (int total, int perc)
 {
-  return static_cast <int> ((total / 100) * perc);
+  return static_cast <int> (total * perc / 100);
+
 }
 
 
